@@ -22,7 +22,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // KDE Frameworks
 #include <KIdleTime>
 // Qt
-#include <QtTest/QtTest>
+#include <QtTest>
 #include <QProcess>
 #include <QX11Info>
 // xcb
@@ -42,6 +42,8 @@ private Q_SLOTS:
 void KSldTest::initTestCase()
 {
     QCoreApplication::setAttribute(Qt::AA_ForceRasterWidgets);
+    // change to the build bin dir
+    QDir::setCurrent(QCoreApplication::applicationDirPath());
 }
 
 void KSldTest::testEstablishGrab()
